@@ -1,6 +1,7 @@
 class ARG(object):
-    def __init__(self, value):
+    def __init__(self, value, lineno):
         self.value = value
+        self.lineno = lineno
 
     def __repr__(self):
         return "ARG(%s)" % repr(self.value)
@@ -9,8 +10,9 @@ class ARG(object):
         return str(self.value)
 
 class FUNC_NAME(object):
-    def __init__(self, value):
+    def __init__(self, value, lineno):
         self.value = value
+        self.lineno = lineno
 
     def __repr__(self):
         return "FUNC_NAME(%s)" % repr(self.value)
@@ -19,8 +21,9 @@ class FUNC_NAME(object):
         return str(self.value)
 
 class VALUE(object):
-    def __init__(self, value):
+    def __init__(self, value, lineno):
         self.value = value
+        self.lineno = lineno
 
     def __repr__(self):
         return "VALUE(%s)" % repr(self.value)
@@ -29,8 +32,9 @@ class VALUE(object):
         return str(self.value)
 
 class ASSIGN(object):
-    def __init__(self, value):
+    def __init__(self, value, lineno):
         self.value = value
+        self.lineno = lineno
 
     def __repr__(self):
         return "ASSIGN(%s)" % repr(self.value)
